#include "comm.h"
#include "io.h"

extern u_int LogSyslog; /* defined in main program */

/*
 * Function: Printf(format,args,...)
 * 
 * Purpose: prints either to stdout or log via syslog depending
 *          on global LogSyslog flag
 *
 * Author: DG
 *
 */
void Printf(char *format,...)
{
  char line[STRLEN]="";
  va_list va_args;

  bzero(line,STRLEN);
  va_start(va_args,format);
  vsnprintf(line,STRLEN-1,format,va_args);
  va_end(va_args);

  if (LogSyslog)
    syslog(LOG_INFO|LOG_LOCAL0,line);
  else
    printf(line);
}


/*
 * Function: DG_strerror_r(errnum,buf,n)
 * 
 * Purpose: Our own version of strerror_r, there are several 
 *          incompatible verions out there, especially glibc 
 *          which returns a char pointer
 *
 * Arguments: error number, buffer to store message, size of buffer
 *
 * Author: DG
 *
 */

int DG_strerror_r(int errnum, char *buf, size_t n)
{
   return snprintf(buf, n, strerror(errnum));
}


/*
 * Function: CheckDirectory
 * 
 * Purpose: Check accessibility of directory to create swap
 *          files for the case the database dies or fails.
 *          We need all rights, read, write and execute to
 *          change in the directory.
 *
 * Arguments: string containing the directory
 *
 * Return:  0 if all is ok
 *         -1 on error
 *
 * Author: DG
 *
 */
int CheckDirectory(char *dir)
{
  char errbuf[STRLEN];

  /* First we check the directory */
  if  (access(dir, R_OK|W_OK|X_OK) <0 )
      {
	DG_strerror_r(errno,errbuf,STRLEN);
	Printf("Acess error on <%s>: %s\n",dir,errbuf);
         return(-1);
       }
    else
      {
#ifdef DEBUG
           Printf("Access ok.\n");
#endif
	   return(0);
       }
}


/*
 * Function: CheckFile
 * 
 * Purpose: Check if a swap file is present and if the size
 *          is greater zero -> we have to read in swapped data
 *
 * Arguments: string containing the file
 *
 * Return:  0 if nothing is to do
 *         -1 on error
 *          1 file is present and not empty
 *
 * Author: DG
 *
 */
int CheckFile(char *file)
{
  char errbuf[STRLEN];
  struct stat buf;

   /* Check if file exits, is accessable and get the size */
    if (stat(file,&buf))
     {
       /* File does not exist */
        DG_strerror_r(errno,errbuf,STRLEN);
        Printf("CheckFile -> %s: %s\n",file, errbuf);
	return(0);
     }
    else
     {
       /* File exists, test if we have rw access */
        if (access(file, R_OK|W_OK) < 0 )
	 {
	   DG_strerror_r(errno,errbuf,STRLEN);
	   Printf("CheckFile, can not access file -> %s: %s\n",file, errbuf);
	   return(-1);
         }
	else
	 {
#ifdef DEBUG
	   Printf("Access on file %s is ok.\n",file);
           Printf("Size: %i\n",(int) buf.st_size);
#endif
           if (buf.st_size>0) return(1);
         }
     }
    return(0);
}

